@@ -27,7 +27,7 @@ background.
 def create_background_guess_arrays (freq, psd, r=1., m=1., teff=5770., 
                                     dnu=None, numax=None,
                                     n_harvey=2, spectro=False, power_law=False, 
-                                    high_cut_plaw=20.) :
+                                    high_cut_plaw=20., return_labels=False) :
   '''
   Create guess and bound arrays for background fit.
 
@@ -72,7 +72,11 @@ def create_background_guess_arrays (freq, psd, r=1., m=1., teff=5770.,
     default 20. 
   :type high_cut_plaw: float
 
-  :return: guess, low bounds and up bounds array
+  :param return_labels: if set to ``True``, the label array will be returned 
+    among the returned tuple of arrays.
+  :type return_labels: bool  
+
+  :return: guess, low bounds, up bounds (and labels if ``return_labels=True``) arrays.
   :rtype: tuple of arrays
   '''
 
@@ -87,9 +91,13 @@ def create_background_guess_arrays (freq, psd, r=1., m=1., teff=5770.,
   low_bounds = get_low_bounds (guess, n_harvey, freq, psd, numax)
   up_bounds = get_up_bounds (guess, n_harvey, freq, psd, numax)
 
-  return guess, low_bounds, up_bounds
+  if return_labels :
+    labels = create_labels (n_harvey)
+    return guess, low_bounds, up_bounds, labels
+  else :
+    return guess, low_bounds, up_bounds
 
-def create_labels (n_harvey, frozen_param) :
+def create_labels (n_harvey, frozen_param=None) :
   '''
   Create array of label to use when plotting MCMC.
   '''
@@ -107,7 +115,8 @@ def create_labels (n_harvey, frozen_param) :
   label.append ('noise')
 
   label = np.array (label)
-  label = label[~frozen_param]
+  if frozen_param is not None :
+    label = label[~frozen_param]
  
   return label
 
@@ -332,7 +341,7 @@ def background_model (freq, param_harvey=None, param_plaw=None,
     model += gauss_env (freq, *param_gaussian) 
   if apodisation :
     nyquist = freq[-1]
-    eta = np.sinc (np.pi / 2 * freq / nyquist) 
+    eta = np.sinc (1 / 2 * freq / nyquist) 
     model = model * eta * eta
   model += noise
 
@@ -534,43 +543,52 @@ def log_probability_back (param_to_fit, freq, psd, bounds, full_param, frozen_pa
   return l_proba
 
 def visualise_background (freq, psd, param_fitted=None, guess=None, low_cut=100., n_harvey=2, 
-                          filename=None, spectro=True, alpha=1., show=False, apodisation=False) :
+                          filename=None, spectro=True, alpha=1., show=False, apodisation=False,
+                          smoothing=50, color_fitted='crimson', color_guess='mediumaquamarine',
+                          **kwargs) :
   '''
   Plot fitted background against real PSD (and possibly against initial guess).
   '''
 
+  psd_smoothed = smooth (psd, smoothing)
+
   if guess is not None :
     guess_harvey, guess_plaw, guess_gaussian, guess_noise = extract_param (guess, n_harvey)
-    guess_model = background_model (freq, guess_harvey, guess_plaw, guess_gaussian, guess_noise, n_harvey, apodisation=apodisation)
+    guess_model = background_model (freq, guess_harvey, guess_plaw, 
+                                    guess_gaussian, guess_noise, 
+                                    n_harvey, apodisation=apodisation)
   if param_fitted is not None :
     fitted_harvey, fitted_plaw, fitted_gaussian, fitted_noise = extract_param (param_fitted, n_harvey)
-    fitted_back = background_model (freq, fitted_harvey, fitted_plaw, fitted_gaussian, fitted_noise, n_harvey, apodisation=apodisation)
+    fitted_back = background_model (freq, fitted_harvey, fitted_plaw, 
+                                    fitted_gaussian, fitted_noise, 
+                                    n_harvey, apodisation=apodisation)
 
   fig = plt.figure (figsize=(12,6))
   ax = fig.add_subplot (111)
 
   ax.plot (freq, psd, color='darkgrey')
   ax.plot (freq[freq>low_cut], psd[freq>low_cut], color='black')
+  ax.plot (freq[freq>low_cut], psd_smoothed[freq>low_cut], color='burlywood')
   if guess is not None :
-    ax.plot (freq, guess_model, color='green')
+    ax.plot (freq, guess_model, color=color_guess, lw=2, label='guess')
     if n_harvey > 0 :
       guess_harvey = np.reshape (guess_harvey, (n_harvey, guess_harvey.size//n_harvey))
       for elt in guess_harvey :
-        ax.plot (freq, harvey (freq, *elt), ':', color='green') 
+        ax.plot (freq, harvey (freq, *elt), ':', color=color_guess) 
     if guess_gaussian[0] > 0 :
-      ax.plot (freq, gauss_env (freq, *guess_gaussian), ':', color='green')
+      ax.plot (freq, gauss_env (freq, *guess_gaussian), ':', color=color_guess)
     if guess_plaw[0]!= 0 :
-      ax.plot (freq, power_law (freq, *guess_plaw), ':', color='green')
+      ax.plot (freq, power_law (freq, *guess_plaw), ':', color=color_guess)
   if param_fitted is not None :
-    ax.plot (freq, fitted_back, color='red', alpha=alpha)
+    ax.plot (freq, fitted_back, color=color_fitted, alpha=alpha, lw=2, label='fitted')
     if n_harvey > 0 :
       fitted_harvey = np.reshape (fitted_harvey, (n_harvey, fitted_harvey.size//n_harvey))
       for elt in fitted_harvey :
-        ax.plot (freq, harvey (freq, *elt), '--', color='red', alpha=alpha) 
+        ax.plot (freq, harvey (freq, *elt), '--', color=color_fitted, alpha=alpha) 
     if fitted_gaussian[0] > 0 :
-      ax.plot (freq, gauss_env (freq, *fitted_gaussian), '--', color='red')
+      ax.plot (freq, gauss_env (freq, *fitted_gaussian), '--', color=color_fitted)
     if fitted_plaw[0]!= 0 :
-      ax.plot (freq, power_law (freq, *fitted_plaw), '--', color='red')
+      ax.plot (freq, power_law (freq, *fitted_plaw), '--', color=color_fitted)
 
   ax.set_xlabel (r'Frequency ($\mu$Hz)')
   if spectro :
@@ -580,11 +598,11 @@ def visualise_background (freq, psd, param_fitted=None, guess=None, low_cut=100.
 
   ax.set_xscale ('log')
   ax.set_yscale ('log')
-
+  ax.legend ()
   ax.set_ylim (0.9*np.amin(psd), 1.1*np.amax(psd))
 
   if filename is not None:
-    plt.savefig (filename, format='pdf')
+    plt.savefig (filename, **kwargs)
 
   if show :
     plt.show ()
@@ -597,8 +615,9 @@ def perform_mle_background (freq, psd, n_harvey=2, r=1., m=1., teff=5770., dnu=N
                             guess=None, frozen_param=None, power_law=False, gaussian=True, 
                             frozen_harvey_exponent=False, low_cut=100., method=_minimize_powell, fit_log=False,
                             low_bounds=None, up_bounds=None, no_bounds=False, show=True, show_guess=False, filename=None, spectro=True,
-                            quickfit=False, num=5000, reboxing_behaviour='advanced_reboxing', reboxing_strategy='median', 
-                            apodisation=False, high_cut_plaw=20.) :
+                            quickfit=False, num=5000, num_numax=500, 
+                            reboxing_behaviour='advanced_reboxing', reboxing_strategy='median', 
+                            apodisation=False, high_cut_plaw=20., **kwargs) :
   '''
   Perform MLE over background model. 
 
@@ -693,9 +712,18 @@ def perform_mle_background (freq, psd, n_harvey=2, r=1., m=1., teff=5770., dnu=N
     Optional, default ``False``. 
   :type quickfit: bool
 
-  :param num: number of points of the logarithmically sampled spectrum if ``quickfit`` is set to ``True``. Optional, default 50.
+  :param num: Only considered if ``quickfit=True``. 
+    Number of point in the resampled PSD, or target number of point
+    for region away from ``numax`` if ``advanced_reboxing`` is selected.
+    Optional, default ``5000``.
   :type num: int
 
+  :param num_numax: Only considered if ``quickfit=True`` 
+    and ``reboxing_behaviour=advanced_reboxing``. 
+    Number of resampling points in the ``numax`` region.
+    Optional, default ``500``.
+  :type num_numax: int
+
   :param reboxing_behaviour: behaviour for ``quickfit`` new power vector computation. It can be ``smoothing``, ``reboxing`` or 
     ``advanced_reboxing``. Optional, default ``advanced_reboxing``. 
   :type reboxing_behaviour: str
@@ -719,13 +747,17 @@ def perform_mle_background (freq, psd, n_harvey=2, r=1., m=1., teff=5770., dnu=N
     dnu = dnu_scale (r, m)
     print ('dnu computed with scaling law: {:.1f} muHz'.format (dnu)) 
   if numax is None :
-    numax = numax_scale (r, m, teff)
-    print ('numax computed with scaling law: {:.1f} muHz'.format (numax)) 
+    if guess is not None :
+      numax = guess[-3]
+    else :
+      numax = numax_scale (r, m, teff)
+      print ('numax computed with scaling law: {:.1f} muHz'.format (numax)) 
 
   lenguess = n_harvey * 3 + 6
 
   if guess is None :
-    guess = background_guess (freq, psd, numax, dnu, m_star=m, n_harvey=n_harvey, spectro=spectro, power_law=power_law,
+    guess = background_guess (freq, psd, numax, dnu, m_star=m, n_harvey=n_harvey, 
+                              spectro=spectro, power_law=power_law,
                               high_cut_plaw=high_cut_plaw) 
 
   elif len (guess) != lenguess :
@@ -752,7 +784,8 @@ def perform_mle_background (freq, psd, n_harvey=2, r=1., m=1., teff=5770., dnu=N
   full_param = np.copy (guess)
 
   if show_guess :
-    visualise_background (freq, psd, guess=guess, low_cut=low_cut, n_harvey=n_harvey, spectro=spectro) 
+    visualise_background (freq, psd, guess=guess, low_cut=low_cut, n_harvey=n_harvey, spectro=spectro,
+                          **kwargs) 
 
   #Bounds
   if no_bounds :
@@ -786,7 +819,8 @@ def perform_mle_background (freq, psd, n_harvey=2, r=1., m=1., teff=5770., dnu=N
   aux_psd = psd[freq>low_cut]
 
   if quickfit :
-    aux_freq, aux_psd = degrade_psd (aux_freq, aux_psd, num=num, behaviour=reboxing_behaviour,
+    aux_freq, aux_psd = degrade_psd (aux_freq, aux_psd, num=num, num_numax=num_numax, 
+                                     behaviour=reboxing_behaviour,
                                      strategy=reboxing_strategy, numax=numax)
   print ('Background model likelihood minimisation:')
   with warnings.catch_warnings () :
@@ -808,7 +842,7 @@ def perform_mle_background (freq, psd, n_harvey=2, r=1., m=1., teff=5770., dnu=N
   fitted_back = background_model (freq, param_harvey, param_plaw, param_gaussian=None, noise=noise, n_harvey=n_harvey, apodisation=apodisation)
 
   visualise_background (freq, psd, param_fitted=full_param, guess=guess, low_cut=low_cut, n_harvey=n_harvey, 
-                          filename=filename, spectro=spectro, show=show) 
+                          filename=filename, spectro=spectro, show=show, **kwargs) 
 
 
   return fitted_back, full_param
@@ -817,11 +851,11 @@ def explore_distribution_background (freq, psd, n_harvey=2, r=1., m=1., teff=577
                                      guess=None, frozen_param=None, power_law=False, gaussian=True, 
                                      frozen_harvey_exponent=False, low_cut=100., fit_log=False,
                                      low_bounds=None, up_bounds=None, spectro=True, show=True, show_guess=False, show_corner=True,
-                                     nsteps=1000, filename=None, parallelise=False, progress=False, nwalkers=64, filemcmc=None,
-                                     coeff_discard=50, thin=1, quickfit=False, num=5000, reboxing_behaviour='advanced_reboxing', 
-                                     reboxing_strategy='median',  
+                                     nsteps=1000, discard=200, filename=None, parallelise=False, progress=False, nwalkers=64, filemcmc=None,
+                                     thin=1, quickfit=False, num=5000, num_numax=500, estimate_autocorrelation=False, 
+                                     reboxing_behaviour='advanced_reboxing', reboxing_strategy='median', format_cornerplot='pdf', 
                                      save_only_after_sampling=False, apodisation=False, high_cut_plaw=20., bins=100,
-                                     existing_chains='read') :
+                                     existing_chains='read', norm=None, **kwargs) :
 
   '''
   Use a MCMC framework to fit the background.  
@@ -918,13 +952,13 @@ def explore_distribution_background (freq, psd, n_harvey=2, r=1., m=1., teff=577
   :param nsteps: number of MCMC steps to perform.
   :type nsteps: int
 
+  :param discard: number of step to discard in the sampling.
+    Optional, default 200.
+  :type discard: int
+
   :param show_guess: if set to ``True``, will show at the beginning a plot summarising the guess. Optional, default ``False``.
   :type show_guess: bool
 
-  :param coeff_discard: coeff used to compute the number of values to discard: total amount of
-    sampled values will be divided by coeff_discard. Optional, default 50.
-  :type coeff_discard: int
-
   :param thin: take only every ``thin`` steps from the chain. Optional, default 1. 
   :type thin: int
 
@@ -932,9 +966,18 @@ def explore_distribution_background (freq, psd, n_harvey=2, r=1., m=1., teff=577
     Optional, default ``False``. 
   :type quickfit: bool
 
-  :param num: number of points of the logarithmically sampled spectrum if ``quickfit`` is set to ``True``. Optional, default 50.
+  :param num: Only considered if ``quickfit=True``. 
+    Number of point in the resampled array, or target number of point
+    for region away from ``numax`` if ``advanced_reboxing`` is selected.
+    Optional, default ``5000``.
   :type num: int
 
+  :param num_numax: Only considered if ``quickfit=True`` 
+    and ``reboxing_behaviour=advanced_reboxing``. 
+    Number of resampling points in the ``numax`` region.
+    Optional, default ``1000``.
+  :type num_numax: int
+
   :param reboxing_behaviour: behaviour for ``quickfit`` new power vector computation. It can be ``smoothing``, ``reboxing`` or 
     ``advanced_reboxing``. Optional, default ``advanced_reboxing``. 
   :type reboxing_behaviour: str
@@ -963,6 +1006,11 @@ def explore_distribution_background (freq, psd, n_harvey=2, r=1., m=1., teff=577
     Optional, default ``read``.
   :type existing_chains: str
 
+  :param estimate_autocorrelation: if set to ``True``, the autocorrelation time
+    of the sampled chains will be estimated by ``emcee``. Optional, default
+    ``False``. 
+  :type estimate_autocorrelation: bool
+
   :return: the fitted param, its param and their sigma values as determined by the MCMC walk.
   :rtype: tuple of array
   '''
@@ -977,9 +1025,15 @@ def explore_distribution_background (freq, psd, n_harvey=2, r=1., m=1., teff=577
     raise Exception ("save_only_after_sampling=True and existing_chains='sample' are incompatible options.")
 
   if dnu is None :
-    dnu = dnu_scale (r, m)
+    if guess is not None :
+      dnu = guess[0]
+    else :
+      dnu = dnu_scale (r, m)
   if numax is None :
-    numax = numax_scale (r, m, teff)
+    if guess is not None :
+      numax = guess[-3]
+    else :
+      numax = numax_scale (r, m, teff)
 
   lenguess = n_harvey * 3 + 6
 
@@ -1011,7 +1065,8 @@ def explore_distribution_background (freq, psd, n_harvey=2, r=1., m=1., teff=577
   full_param = np.copy (guess)
 
   if show_guess :
-    visualise_background (freq, psd, guess=guess, low_cut=low_cut, n_harvey=n_harvey, spectro=spectro) 
+    visualise_background (freq, psd, guess=guess, low_cut=low_cut, n_harvey=n_harvey, spectro=spectro,
+                          **kwargs) 
 
   #Bounds
   if low_bounds is None :
@@ -1038,7 +1093,8 @@ def explore_distribution_background (freq, psd, n_harvey=2, r=1., m=1., teff=577
 
   bounds = np.c_[low_bounds, up_bounds]
 
-  norm = np.abs (param)
+  if norm is None :
+    norm = np.abs (param)
 
   if parallelise :
     pool = ProcessPool ()
@@ -1090,7 +1146,8 @@ def explore_distribution_background (freq, psd, n_harvey=2, r=1., m=1., teff=577
 
   if run_sampler :
     if quickfit :
-      aux_freq, aux_psd = degrade_psd (aux_freq, aux_psd, num=num, behaviour=reboxing_behaviour,  
+      aux_freq, aux_psd = degrade_psd (aux_freq, aux_psd, num=num, num_numax=num_numax, 
+                                       behaviour=reboxing_behaviour,  
                                        strategy=reboxing_strategy, numax=numax)
 
     print ('Beginning fit')
@@ -1104,10 +1161,15 @@ def explore_distribution_background (freq, psd, n_harvey=2, r=1., m=1., teff=577
       if save_only_after_sampling :
         save_sampled_chain (filemcmc, sampler, ndim, nwalkers, nsteps)
 
-  discard = nsteps // coeff_discard
-
   if show_corner :
-    make_cornerplot (sampler, ndim, discard, thin, labels, norm, filemcmc=filemcmc, bins=bins)
+    make_cornerplot (sampler, ndim, discard, thin, 
+                     labels, norm, filemcmc=filemcmc, 
+                     bins=bins, format_cornerplot=format_cornerplot,
+                     **kwargs)
+
+  # Estimating autocorrelation time
+  if estimate_autocorrelation :
+    taus = sampler.get_autocorr_time (discard=discard, thin=thin, quiet=True)
 
   flat_samples = sampler.get_chain(discard=discard, thin=thin, flat=True)
   centiles = np.percentile(flat_samples, [16, 50, 84], axis=0) * norm 
@@ -1123,10 +1185,12 @@ def explore_distribution_background (freq, psd, n_harvey=2, r=1., m=1., teff=577
   full_sigma[~frozen_param] = sigma_back
   param_harvey, param_plaw, param_gaussian, noise = extract_param (full_param, n_harvey)
   # We want the background without the gaussian envelope
-  fitted_back = background_model (freq, param_harvey, param_plaw, param_gaussian=None, noise=noise, n_harvey=n_harvey, apodisation=apodisation)
+  fitted_back = background_model (freq, param_harvey, param_plaw, 
+                                  param_gaussian=None, noise=noise, 
+                                  n_harvey=n_harvey, apodisation=apodisation)
 
   visualise_background (freq, psd, param_fitted=full_param, guess=guess, low_cut=low_cut, n_harvey=n_harvey, 
-                          filename=filename, spectro=spectro, alpha=0.8, show=show) 
+                          filename=filename, spectro=spectro, alpha=0.8, show=show, **kwargs) 
 
   return fitted_back, full_param, full_sigma
 
