@@ -194,7 +194,12 @@ def chain_to_a2z (filename, thin=1, discard=0, add_ampl=False, instr='geometric'
   df.loc[:,1] = degrees
   df.loc[:,2] = labels
   df.loc[labels!='a',3] = 'mode'
-  df.loc[labels=='a',3] = 'order'
+  if 'degrees_02' in path.basename (filename) :  
+    df.loc[labels=='a',3] = 'even'
+  elif 'degrees_13' in path.basename (filename) :  
+    df.loc[labels=='a',3] = 'odd'
+  else :
+    df.loc[labels=='a',3] = 'order'
   df.loc[:,4] = centiles[1,:]
 
   #retransforming width and heights
@@ -276,7 +281,12 @@ def chain_to_centile_frame (filename, thin=1, discard=0, add_ampl=False, instr='
   df.loc[:,1] = degrees
   df.loc[:,2] = labels
   df.loc[labels!='a',3] = 'mode'
-  df.loc[labels=='a',3] = 'order'
+  if 'degrees_02' in path.basename (filename) :  
+    df.loc[labels=='a',3] = 'even'
+  elif 'degrees_13' in path.basename (filename) :  
+    df.loc[labels=='a',3] = 'odd'
+  else :
+    df.loc[labels=='a',3] = 'order'
   df.loc[:,4] = centiles[1,:]
 
   #retransforming width and heights
