@@ -19,6 +19,19 @@ import corner
 import numba
 import warnings
 
+def scaling_laws (numax, dnu, teff, 
+                  dnu_sun=135, numax_sun=3050, 
+                  teff_sun=5770) :
+  '''
+  Compute stellar mass and radius from scaling 
+  laws (output returned in solar mass and radius).
+  '''
+
+  r = (dnu_sun / dnu)**2 * numax/numax_sun * (teff/teff_sun)**(1/2)
+  m = (dnu_sun / dnu)**4 * (numax/numax_sun)**3 * (teff/teff_sun)**(3/2)
+
+  return r, m
+
 def make_header_utility_file () :
   header = 'Utility file with normalisation parameters and parameters info'
   return header
@@ -159,7 +172,7 @@ def complete_pkb (pkb, l1_as_ref) :
 
   return pkb
 
-def check_a2z (df, verbose=False) :
+def check_a2z (df, strategy='order', verbose=False) :
 
   '''
   Check bound validity for any a2z DataFrame. Line with ``global`` mention
@@ -168,15 +181,19 @@ def check_a2z (df, verbose=False) :
 
   df = df.loc[df[3]!='global'] 
 
+  if strategy!='pair':
+    if np.any (df[3]=='even') or np.any (df[3]=='odd') :
+      raise Exception ('a2z input odd and even keywords can be used only with strategy=pair')
+
   if np.any (df[4] < df[7]) :
-    print ('Guess below low_bounds')
+    print ('Guess in a2z DataFrame below low_bounds')
     print (df.loc[df[4]<df[7]])
   if np.any (df[4] > df[8]) :
-    print ('Guess below low_bounds')
+    print ('Guess in a2z DataFrame below low_bounds')
     print (df.loc[df[4]>df[8]])
 
   if (np.any (df[4] < df[7]) | np.any (df[4] > df[8]) ) :
-    raise Exception ('Guess is outside of provided bounds')
+    raise Exception ('Guess in a2z DataFrame is outside of provided bounds')
 
   if verbose :
     print ('Input bounds are ok.')
@@ -203,7 +220,9 @@ def check_bounds (param, low_bounds, up_bounds, labels=None) :
 
 
 def make_cornerplot (sampler, ndim, discard, thin, labels, 
-                     norm=None, filemcmc=None, bins=100) :
+                     norm=None, filemcmc=None, bins=100,
+                     format_cornerplot='pdf',
+                     **kwargs) :
   '''
   Wrapper to make cornerplots.
 
@@ -246,7 +265,7 @@ def make_cornerplot (sampler, ndim, discard, thin, labels,
       if yi!=ndim-1 :
         ax.xaxis.set_ticklabels ([])
   if filemcmc is not None :
-    plt.savefig (filemcmc[:len(filemcmc[:-3])]+'_cornerplot.pdf', format='pdf') 
+    plt.savefig (path.splitext (filemcmc)[0]+'_cornerplot.{}'.format(format_cornerplot), **kwargs) 
   plt.close ()
 
   return
@@ -342,14 +361,14 @@ def merge_a2z_file (file1, file2) :
 
 def save_pkb (filename, pkb, author=None, spectro=False, extended=False,
               fmt=None, projected_splittings=False, nwalkers=None, nsteps=None,
-              coeff_discard=None, fit_amp=False) :
+              discard=None, fit_amp=False) :
   '''
   Save pkb file with dedicated header.
   '''
 
   header = make_header_pkb (extended=extended, author=author, spectro=spectro,
                             projected_splittings=projected_splittings, nwalkers=nwalkers,
-                            nsteps=nsteps, coeff_discard=coeff_discard, fit_amp=fit_amp)
+                            nsteps=nsteps, discard=discard, fit_amp=fit_amp)
   if fmt is None :
     if extended :
       fmt = ['%.0f', '%.0f', '%.4f', '%.4f', '%.4f', '%.4f', '%.4f', '%.4f',
@@ -440,7 +459,7 @@ def a2z_to_pkb (df_a2z, nopandas=True) :
   else :
     raise Exception ('nopandas=False is deprecated and cannot be used anymore.')
     
-def pkb_to_latex (pkb) :
+def pkb_to_df (pkb) :
   '''
   Convert a pkb array into a tabular latex string
 
@@ -451,10 +470,61 @@ def pkb_to_latex (pkb) :
   :rtype: str
   '''
 
-  columns = [] #TODO
-  dtype = [] #TODO
-  df = pd.DataFrame (data=pkb, columns=columns, dtype=dtype)
-  latex_tabular = df.to_latex (index=False)
+  if pkb.shape[1]==20 :
+    columns = [r'$n$', r'$\ell$', r'$\nu$', r'$\sigma_{\nu,-}$', r'$\sigma_{\nu,+}$',
+               r'$H$', r'$\sigma_{H,-}$', r'$\sigma_{H,+}$', 
+               r'$\Gamma$', r'$\sigma_{\Gamma,-}$', r'$\sigma_{\Gamma,+}$',
+               r'$i$', r'$\sigma_{i,-}$', r'$\sigma_{i,+}$',
+               r'$s$', r'$\sigma_{s,-}$', r'$\sigma_{s,+}$',
+               r'$\alpha$', r'$\sigma_{\alpha,-}$', r'$\sigma_{\alpha,+}$'] 
+  else :
+    columns = [r'$n$', r'$\ell$', r'$\nu$', r'$\sigma_{\nu}$',
+               r'$H$', r'$\sigma_{H}$' 
+               r'$\Gamma$', r'$\sigma_{\Gamma}$',
+               r'$i$', r'$\sigma_{i}$',
+               r'$s$', r'$\sigma_{s}$',
+               r'$\alpha$', r'$\sigma_{\alpha}$'] 
+  df = pd.DataFrame (data=pkb, columns=columns)
+  df[r'$n$'] = df[r'$n$'].map (int)
+  df[r'$\ell$'] = df[r'$\ell$'].map (int)
+
+  return df
+
+def pkb_to_latex (pkb, buf=None, caption=None, label=None) :
+  '''
+  Convert a pkb array into a tabular latex string.
+
+  :param pkb: pkb array
+  :type: ndarray
+
+  :return: latex tabular
+  :rtype: str
+  '''
+
+  df = pd.DataFrame (data=pkb)
+  df[0] = df[0].map (int)
+  df[1] = df[1].map (int)
+  tab = df[[0,1]].copy ()
+  tab = tab.rename (columns={0:r'$n$', 1:r'$\ell$'})
+  if pkb.shape[1]==20 :
+    txt = '${0:.2f}_{{-{1:.2f}}}^{{+{2:.2f}}}$'
+    tab[r'$\nu$'] = df.apply (lambda df : txt.format (df[2], df[3], df[4]), axis=1)
+    tab[r'$H$'] = df.apply (lambda df : txt.format (df[5], df[6], df[7]), axis=1)
+    tab[r'$\Gamma$'] = df.apply (lambda df : txt.format (df[8], df[9], df[10]), axis=1)
+    tab[r'$i$'] = df.apply (lambda df : txt.format (df[11], df[12], df[13]), axis=1)
+    tab[r'$s$'] = df.apply (lambda df : txt.format (df[14], df[15], df[16]), axis=1)
+    tab[r'$\alpha$'] = df.apply (lambda df : txt.format (df[17], df[18], df[19]), axis=1)
+  else :
+    txt = '${{0:.2f}} \pm {{1:.2f}}$'
+    tab[r'$\nu$'] = df.apply (lambda df : txt.format (df[2], df[3]), axis=1)
+    tab[r'$H$'] = df.apply (lambda df : txt.format (df[4], df[5]), axis=1)
+    tab[r'$\Gamma$'] = df.apply (lambda df : txt.format (df[6], df[7]), axis=1)
+    tab[r'$i$'] = df.apply (lambda df : txt.format (df[8], df[9]), axis=1)
+    tab[r'$s$'] = df.apply (lambda df : txt.format (df[10], df[11]), axis=1)
+    tab[r'$\alpha$'] = df.apply (lambda df : txt.format (df[12], df[13]), axis=1)
+
+  latex_tabular = tab.to_latex (index=False, escape=False, buf=buf,
+                                caption=caption, label=label)
 
   return latex_tabular
 
@@ -585,10 +655,30 @@ def compute_model (freq, param_pkb, param_wdw=None, correct_width=1., instr='kep
         for elt_wdw in param_wdw :
           nu0 = elt[2] + m*splitting + elt_wdw[1] 
           G = elt[6] * correct_width
-          xxx = (freq - nu0) / G
           asym = elt[12]
           A = ampl_mode (int(elt[1]), m, angle, np.sin (angle), np.cos (angle), instr=instr) * H * elt_wdw[0] 
 
+          if A > 0 : #avoid computing null terms
+            xxx = (freq - nu0) / G
+            if not use_sinc :
+              if asym_profile=='korzennik' :
+                num = A * (1 + asym*(xxx - asym/2.))
+              if asym_profile=='nigam-kosovichev' :
+                num = A * ((1 + asym*xxx)*(1 + asym*xxx) + asym*asym)
+              if np.any (num < 0) :
+                return np.full (model.size, np.inf) #avoid case where asymetries make a negative height
+              model += num / (1. + 4. * xxx * xxx) 
+            else :
+              model += A * np.sinc (xxx) * np.sinc (xxx)
+
+      else :
+        nu0 = elt[2] + m*splitting
+        G = elt[6]
+        asym = elt[12]
+        A = ampl_mode (int (elt[1]), m, angle, np.sin (angle), np.cos (angle), instr=instr) * H 
+
+        if A > 0 : #avoid computing null terms
+          xxx = (freq - nu0) / G
           if not use_sinc :
             if asym_profile=='korzennik' :
               num = A * (1 + asym*(xxx - asym/2.))
@@ -600,29 +690,11 @@ def compute_model (freq, param_pkb, param_wdw=None, correct_width=1., instr='kep
           else :
             model += A * np.sinc (xxx) * np.sinc (xxx)
 
-      else :
-        nu0 = elt[2] + m*splitting
-        G = elt[6]
-        xxx = (freq - nu0) / G
-        asym = elt[12]
-        A = ampl_mode (int (elt[1]), m, angle, np.sin (angle), np.cos (angle), instr=instr) * H 
-
-        if not use_sinc :
-          if asym_profile=='korzennik' :
-            num = A * (1 + asym*(xxx - asym/2.))
-          if asym_profile=='nigam-kosovichev' :
-            num = A * ((1 + asym*xxx)*(1 + asym*xxx) + asym*asym)
-          if np.any (num < 0) :
-            return np.full (model.size, np.inf) #avoid case where asymetries make a negative height
-          model += num / (1. + 4. * xxx * xxx) 
-        else :
-          model += A * np.sinc (xxx) * np.sinc (xxx)
-
   return model
 
 def plot_from_param (param_pkb, freq, psd, back=None, wdw=None, smoothing=50, spectro=True, correct_width=1.,
                      show=False, filename=None, instr='geometric', use_sinc=False, asym_profile='korzennik',
-                     projected_splittings=False) :
+                     projected_splittings=False, **kwargs) :
   """
   Plot the results of a fit according to an input given with a pkb format.
 
@@ -727,6 +799,7 @@ def plot_from_param (param_pkb, freq, psd, back=None, wdw=None, smoothing=50, sp
   fig = plt.figure (figsize=(10,10))
   capsize=2.5
   labelpad=0
+  slabel=9
 
   #PSD centered on fitted p-mode
   ax1 = fig.add_subplot (321) 
@@ -756,11 +829,11 @@ def plot_from_param (param_pkb, freq, psd, back=None, wdw=None, smoothing=50, sp
 
   #Height
   ax4 = fig.add_subplot (324, sharex=ax1) 
-  ax4.errorbar (f0, h0, yerr=eh0, marker='x', fmt='r ', label='l0', capsize=capsize)
-  ax4.errorbar (f1, h1, yerr=eh1, marker='x', fmt='b ', label='l1', capsize=capsize)
-  ax4.errorbar (f2, h2, yerr=eh2, marker='x', fmt='g ', label='l2', capsize=capsize)
-  ax4.errorbar (f3, h3, yerr=eh3, marker='x', fmt='y ', label='l3', capsize=capsize)
-  ax4.legend ()
+  ax4.errorbar (f0, h0, yerr=eh0, marker='x', fmt='r ', label=r'$\ell = 0$', capsize=capsize)
+  ax4.errorbar (f1, h1, yerr=eh1, marker='x', fmt='b ', label=r'$\ell = 1$', capsize=capsize)
+  ax4.errorbar (f2, h2, yerr=eh2, marker='x', fmt='g ', label=r'$\ell = 2$', capsize=capsize)
+  ax4.errorbar (f3, h3, yerr=eh3, marker='x', fmt='y ', label=r'$\ell = 3$', capsize=capsize)
+  ax4.legend (fontsize=slabel, ncol=2)
 
   #Width
   ax5 = fig.add_subplot (325, sharex=ax1) 
@@ -770,7 +843,6 @@ def plot_from_param (param_pkb, freq, psd, back=None, wdw=None, smoothing=50, sp
   ax5.errorbar (f3, w3, yerr=ew3, marker='x', fmt='y ', capsize=capsize)
 
   #label
-  slabel=9
 
   ax1.set_xlabel (r'Frequency ($\mu$Hz)', labelpad=labelpad, size=slabel)
   ax2.set_xlabel (r'Frequency ($\mu$Hz)', labelpad=labelpad, size=slabel)
@@ -814,11 +886,16 @@ def plot_from_param (param_pkb, freq, psd, back=None, wdw=None, smoothing=50, sp
                      ylim=(freq[(freq > center - n_dnu * dnu)&(freq < center + n_dnu * dnu)][0],
                            freq[(freq > center - n_dnu * dnu)&(freq < center + n_dnu * dnu)][-1]),
                      shading='gouraud')
+    ax6 = fig.get_axes ()[-1]
+    ax6.tick_params(direction='in', labelsize=8, top=True, right=True)
+    ax6.xaxis.label.set_size (slabel)
+    ax6.yaxis.label.set_size (slabel)
+   
   except (FloatingPointError, RuntimeWarning, ValueError) :
     warnings.warn ("Echelle diagram could not be computed on summary plot.", Warning)
 
   if filename is not None :
-    plt.savefig (filename)
+    plt.savefig (filename, **kwargs)
   if show==True :
     plt.show()
   plt.close ()
