@@ -377,106 +377,6 @@ def list_order_to_fit (numax, Dnu, n_order=3) :
 
   return orders
 
-def hide_modes (freq, psd, pkb, back, l=1, n_width=4, 
-                remove_left=True, remove_zero_bin=True) :
-  '''
-  Hide PSD region around modes of given l.
-
-  :param freq: frequency vector
-  :type freq: ndarray
-
-  :param psd: power vector
-  :type psd: ndarray
-
-  :param back: background power vector
-  :type back: ndarray
-
-  :param pkb: pkb array with modes parameters.
-  :type pkb: ndarray
-
-  :param l: mode degrees to remove. Optional, default ``1``.
-  :type l: int
-
-  :param n_width: frequency bins will be removed ``n_width`` from 
-    the central frequency of the remaining modes. Optional, default ``4``.
-  :type n_width: float
-
-  :param remove_left: if set to ``True``, remove a region Dnu/2 wide
-    before the first mode given in the pkb. Optional, default ``True``. 
-  :type remove_left: bool
-
-  :param remove_zero_bin: if set to ``True``, bins with zero values will be removed from
-    returned vector. Optional, default ``True``.
-  :type remove_zero_bin: bool 
-  '''
-
-  psd = np.copy (psd)
-  dnu = np.mean (np.diff (pkb[pkb[:,1]==0, 2]))
-  if pkb.shape[1]==20 :
-    i_width = 8
-  else :
-    i_width = 6
-
-  if remove_left : 
-    w = pkb[0,i_width]
-    f = pkb[0,2]
-    cond = (freq>f-dnu/2)&(freq<f-n_width*w) 
-    psd[cond] = 0 
-
-  for ii, elt in enumerate (pkb) :
-    if elt[1]==l :
-      w = elt[i_width]
-      if ii > 0 :
-        f1 = pkb[ii-1, 2]
-      else :
-        f1 = elt[2] - dnu/2
-      if ii+1 < pkb.shape[0] :
-        f2 = pkb[ii+1, 2]
-      else :
-        f2 = elt[2] + dnu/2
-      cond = (freq>f1+n_width*w)&(freq<f2-n_width*w) 
-      psd[cond] = 0
-
-  if remove_zero_bin :
-    freq = freq[psd!=0]  
-    back = back[psd!=0]  
-    psd = psd[psd!=0]  
-  
-  return freq, psd, back
-
-def remove_pattern (freq, psd, back, pkb, l=[0,2]) :
-  '''
-  Remove a given pattern from the PSD by dividing the
-  PSD by the computed model.  
-
-  :param freq: frequency vector
-  :type freq: ndarray
-
-  :param psd: power vector
-  :type psd: ndarray
-
-  :param back: background power vector
-  :type back: ndarray
-
-  :param pkb: pkb array with modes parameters.
-  :type pkb: ndarray
-
-  :param l: mode degrees to remove. Optional, default ``[0,2]``.
-  :type l: int or array-like
-  '''
-
-  if pkb.shape[1]==20 :
-    raise Exception ('This function cannot be used with an extended pkb array.' //
-                     'Use a classical pkb instead.')
-
-  pkb = pkb[np.isin (pkb[:,1], l),:]
-
-  model = compute_model (freq, pkb)
-  model = model + back
-  psd = psd / model
-
-  return psd
-
 def override_epsilon (epsilon, param, bounds, mcmc=True) :
   ''' 
   Override epsilon value from what was computed by ``first_guess_mle`` and 
@@ -689,11 +589,13 @@ def pattern_to_a2z (eps, alpha, Dnu, numax, Hmax, Wenv, w, d02, b02=0., d01=None
   df.loc [df[2]=='height', 4] = Hmax * np.exp (-0.5 * np.power ((nu0 - numax)/Wenv, 2))
   df.loc [df[2]=='width', 4] = w
   #bounds for freq
-  df.loc[df[2]=='freq',7] = df.loc[df[2]=='freq',4] - 3.e-3 * numax #this parameter is arbitrary and maybe will
-  df.loc[df[2]=='freq',8] = df.loc[df[2]=='freq',4] + 3.e-3 * numax #have to be modified in the future
+  #this parameter is arbitrary and maybe will
+  #have to be modified in the future           
+  df.loc[df[2]=='freq',7] = df.loc[df[2]=='freq',4] - 3.e-3 * numax - 1.*np.abs (nmax - df.loc[df[2]=='freq',0].astype (int)) 
+  df.loc[df[2]=='freq',8] = df.loc[df[2]=='freq',4] + 3.e-3 * numax       
   if d13 is not None :
     df.loc[df[1]=='3', 8] = df.loc[df[1]=='3', 4] + d13 / 2 #setting bounds to avoid fitting l=3 over l=1 
-    df.loc[df[1]=='1', 7] = df.loc[df[1]=='1', 4] - d13 / 2 
+    #df.loc[df[1]=='1', 7] = df.loc[df[1]=='1', 4] - d13 / 2 
   # bounds for width and height
   df.loc[df[2]=='width',7] = 0.01 * df.loc[df[2]=='width',4]
   df.loc[df[2]=='width',8] = 10. * df.loc[df[2]=='width',4]
@@ -735,7 +637,7 @@ def pattern_to_a2z (eps, alpha, Dnu, numax, Hmax, Wenv, w, d02, b02=0., d01=None
   err = np.zeros (6)
   fixed = np.zeros (6)
   l_bound = np.zeros (6)
-  h_bound = np.array ([max (1., 0.5*split), 90., 3., 3., 3., 3.])
+  h_bound = np.array ([max (1., 2.*split), 90., 3., 3., 3., 3.])
   data = np.c_[index_n, index_l, param, extent, value, err, fixed, l_bound, h_bound]
   df_glob = pd.DataFrame (data=data) 
   df_glob = df_glob.astype (dtype={4:np.float_, 5:np.float_, 6:np.float_, 7:np.float_, 8:np.float_})
@@ -949,7 +851,8 @@ def log_probability_pattern (param_to_fit, freq, psd, bounds, back, orders, spli
 
 def visualise (param_pattern, freq, psd, back, param_pattern_2=None, filename=None, 
                orders=None, split=0, angle=90, snr=True, param_wdw=None, show=False,
-               amp_l=[1., 1.5, 0.7, 0.2]) :
+               amp_l=[1., 1.5, 0.7, 0.2], color_fitted='crimson', 
+               color_guess='mediumaquamarine', **kwargs) :
   '''
   Allow to visualise the considered global_model. May take an optional argument 
   param_pattern_2 to compare two patterns (for example guess and model fitted). 
@@ -996,7 +899,7 @@ def visualise (param_pattern, freq, psd, back, param_pattern_2=None, filename=No
   else : 
     model += back
   
-  psd_s = smooth (psd, 50) #smoothing of psd
+  psd_s = smooth (psd, 30) 
 
   ax.plot (freq, psd, color='darkgrey')
   ax.plot (freq, psd_s, color='black')
@@ -1009,19 +912,19 @@ def visualise (param_pattern, freq, psd, back, param_pattern_2=None, filename=No
       model_2 = model_2 / back + 1.
     else : 
       model_2 += back
-    ax.plot (freq, model_2, '--', color='green')
-
-  ax.plot (freq, model, color='red')
+    ax.plot (freq, model_2, '--', color=color_guess, label='guess')
 
+  ax.plot (freq, model, color=color_fitted, label='fitted')
+  ax.legend ()
   ax.set_xlabel (r'Frequency ($\mu$Hz)')
 
   if snr :
-    ax.set_ylabel ('PSD (signal to noise ratio)')
+    ax.set_ylabel ('PSD (S/N)')
   else :
     ax.set_ylabel ('PSD')
 
   if filename is not None :
-    plt.savefig (filename)
+    plt.savefig (filename, **kwargs)
 
   if show :
     plt.show ()
@@ -1036,7 +939,7 @@ def perform_mle_pattern (Dnu, numax, Hmax, Wenv, Teff, freq, psd,
                          mass=None, guess=None, low_bounds=None, up_bounds=None,
                          show=True, filename=None, epsilon=None, width=None, 
                          alpha=None, d02=None, d01=None, d13=None,
-                         amp_l=[1., 1.5, 0.7, 0.2]) :
+                         amp_l=[1., 1.5, 0.7, 0.2], **kwargs) :
                         
   '''
   Perform minimization of the log likelihood function according to the parameters set to vary.
@@ -1223,7 +1126,8 @@ def perform_mle_pattern (Dnu, numax, Hmax, Wenv, Teff, freq, psd,
   df_a2z = pattern_to_a2z (*param_fitted, split=split, angle=angle, orders=orders, amp_l=amp_l)
 
   visualise (param_fitted, aux_freq, aux_psd*aux_back, aux_back, param_pattern_2=guess, filename=filename,
-               orders=orders, split=split, angle=angle, snr=True, param_wdw=param_wdw, show=show, amp_l=amp_l) 
+             orders=orders, split=split, angle=angle, snr=True, param_wdw=param_wdw, show=show, amp_l=amp_l,
+             **kwargs) 
 
   return df_a2z, param_fitted
 
@@ -1234,12 +1138,13 @@ def explore_distribution_pattern (Dnu, numax, Hmax, Wenv, Teff, freq,
                                   low_bounds=None, up_bounds=None, show=True,
                                   show_corner=True, nsteps=1000, filename=None, 
                                   parallelise=False, progress=False, 
-                                  nwalkers=64, filemcmc=None, coeff_discard=50, 
+                                  nwalkers=64, filemcmc=None, discard=200, 
                                   thin=1, save_only_after_sampling=False,
                                   epsilon=None, width=None, alpha=None, d02=None,
-                                  d01=None, d13=None,
-                                  bins=100, existing_chains='read', 
-                                  amp_l=[1., 1.5, 0.7, 0.2]) :
+                                  d01=None, d13=None, format_cornerplot='pdf',
+                                  bins=100, existing_chains='read', norm=None, 
+                                  amp_l=[1., 1.5, 0.7, 0.2], estimate_autocorrelation=False, 
+                                  **kwargs) :
                         
   '''
   Perform minimization of the log likelihood function according to the parameters set to vary.
@@ -1310,9 +1215,8 @@ def explore_distribution_pattern (Dnu, numax, Hmax, Wenv, Teff, freq,
     If ``filemcmc`` is specified, the plot will also be saved as a pdf file. Optional, default ``True``.
   :type show: bool
 
-  :param coeff_discard: coeff used to compute the number of values to discard: total amount of
-    sampled values will be divided by coeff_discard. Optional, default 50.
-  :type coeff_discard: int
+  :param discard: number of steps to discard in the sampling.
+  :type discard: int
 
   :param thin: take only every ``thin`` steps from the chain. Optional, default 1. 
   :type thin: int
@@ -1354,6 +1258,11 @@ def explore_distribution_pattern (Dnu, numax, Hmax, Wenv, Teff, freq,
     Optional, default ``read``.
   :type existing_chains: str
 
+  :param estimate_autocorrelation: if set to ``True``, the autocorrelation time
+    of the sampled chains will be estimated by ``emcee``. Optional, default
+    ``False``. 
+  :type estimate_autocorrelation: bool
+
   :return: updated df_a2z with relevant sigmas as determined by the MCMC walks.
   :rtype: pandas DataFrame
   '''
@@ -1437,8 +1346,9 @@ def explore_distribution_pattern (Dnu, numax, Hmax, Wenv, Teff, freq,
   aux_psd = (psd/back)[(freq>low_bound_freq)&(freq<up_bound_freq)]
   aux_back = back[(freq>low_bound_freq)&(freq<up_bound_freq)]
 
-  norm = np.abs (param)
-  norm[norm==0] = 1
+  if norm is None :
+    norm = np.abs (param)
+    norm[norm==0] = 1
 
   if parallelise :
     pool = ProcessPool ()
@@ -1501,10 +1411,14 @@ def explore_distribution_pattern (Dnu, numax, Hmax, Wenv, Teff, freq,
       if save_only_after_sampling :
         save_sampled_chain (filemcmc, sampler, ndim, nwalkers, nsteps)
 
-  discard = nsteps // coeff_discard
-
   if show_corner :
-    make_cornerplot (sampler, ndim, discard, thin, labels, norm, filemcmc=filemcmc, bins=bins)
+    make_cornerplot (sampler, ndim, discard, thin, 
+                     labels, norm, filemcmc=filemcmc, bins=bins,
+                     format_cornerplot=format_cornerplot, **kwargs)
+
+  # Estimating autocorrelation time
+  if estimate_autocorrelation :
+    taus = sampler.get_autocorr_time (discard=discard, thin=thin, quiet=True)
 
   flat_samples = sampler.get_chain(discard=discard, thin=thin, flat=True)
   centiles = np.percentile(flat_samples, [16, 50, 84], axis=0) * norm 
@@ -1520,7 +1434,8 @@ def explore_distribution_pattern (Dnu, numax, Hmax, Wenv, Teff, freq,
   df_a2z = pattern_to_a2z (*param_fitted, split=split, angle=angle, orders=orders, amp_l=amp_l)
 
   visualise (param_fitted, aux_freq, aux_psd*aux_back, aux_back, param_pattern_2=guess, filename=filename,
-             orders=orders, split=split, angle=angle, snr=True, param_wdw=param_wdw, show=show, amp_l=amp_l) 
+             orders=orders, split=split, angle=angle, snr=True, param_wdw=param_wdw, show=show, amp_l=amp_l,
+             **kwargs) 
 
   return df_a2z, param_fitted, sigma_fitted
 
