@@ -8,7 +8,7 @@ and manage headers of output files.
 '''
 
 def make_header_background_param (n_harvey=2, author=None, mcmc=True,
-                                  nwalkers=None, nsteps=None, coeff_discard=None, 
+                                  nwalkers=None, nsteps=None, discard=None, 
                                   apodisation=False, quickfit=False, reboxing_behaviour=None,
                                   low_cut=None) :
   '''
@@ -24,7 +24,7 @@ def make_header_background_param (n_harvey=2, author=None, mcmc=True,
   if author is not None :
     header = header + 'Peakbagging performed by ' + author + ' with apollinaire (v' + str(__version__) + ') \n' 
   else :
-    header = header + 'Peakbagging performed by with apollinaire (v' + str(__version__) + ') \n' 
+    header = header + 'Peakbagging performed with apollinaire (v' + str(__version__) + ') \n' 
   header = header + 'https://apollinaire.readthedocs.io/en/latest \n' 
   header = header + 'File creation date: ' + dt_string + '\n' 
 
@@ -42,8 +42,8 @@ def make_header_background_param (n_harvey=2, author=None, mcmc=True,
     str_args += 'nwalkers=' + str (nwalkers) + '\n' 
   if nsteps is not None :
     str_args += 'nsteps=' + str (nsteps) + '\n' 
-  if coeff_discard is not None :
-    str_args += 'discarded_steps=' + str (nsteps//coeff_discard) + '\n' 
+  if discard is not None :
+    str_args += 'discarded_steps=' + str (discard) + '\n' 
   if quickfit is not None :
     str_args += 'quickfit=' + str (quickfit) + '\n' 
   if reboxing_behaviour is not None :
@@ -54,7 +54,7 @@ def make_header_background_param (n_harvey=2, author=None, mcmc=True,
   return header
 
 def make_header_background_vector (author=None, nwalkers=None, nsteps=None, 
-                                   coeff_discard=None, apodisation=False, quickfit=False, 
+                                   discard=None, apodisation=False, quickfit=False, 
                                    reboxing_behaviour=None, low_cut=None) :
   '''
   Design header for saving background power vector file.
@@ -66,7 +66,7 @@ def make_header_background_vector (author=None, nwalkers=None, nsteps=None,
   if author is not None :
     header = header + 'Peakbagging performed by ' + author + ' with apollinaire (v' + str(__version__) + ') \n'
   else :
-    header = header + 'Peakbagging performed by with apollinaire (v' + str(__version__) + ') \n' 
+    header = header + 'Peakbagging performed with apollinaire (v' + str(__version__) + ') \n' 
   header = header + 'https://apollinaire.readthedocs.io/en/latest \n' 
   header = header + 'File creation date: ' + dt_string + '\n' 
 
@@ -78,8 +78,8 @@ def make_header_background_vector (author=None, nwalkers=None, nsteps=None,
     str_args += 'nwalkers=' + str (nwalkers) + '\n' 
   if nsteps is not None :
     str_args += 'nsteps=' + str (nsteps) + '\n' 
-  if coeff_discard is not None :
-    str_args += 'discarded_steps=' + str (nsteps//coeff_discard) + '\n' 
+  if discard is not None :
+    str_args += 'discarded_steps=' + str (discard) + '\n' 
   if quickfit is not None :
     str_args += 'quickfit=' + str (quickfit) + '\n' 
   if reboxing_behaviour is not None :
@@ -90,7 +90,7 @@ def make_header_background_vector (author=None, nwalkers=None, nsteps=None,
   return header
 
 def make_header_pattern (author=None, fit_l1=True, fit_l3=False,
-                         nwalkers=None, nsteps=None, coeff_discard=None,
+                         nwalkers=None, nsteps=None, discard=None,
                          n_order=None) :
   '''
   Design header for saving pattern parameters file.
@@ -111,7 +111,7 @@ def make_header_pattern (author=None, fit_l1=True, fit_l3=False,
   if author is not None :
     header = header + 'Peakbagging performed by ' + author + ' with apollinaire (v' + str(__version__) + ') \n'
   else :
-    header = header + 'Peakbagging performed by with apollinaire (v' + str(__version__) + ') \n' 
+    header = header + 'Peakbagging performed with apollinaire (v' + str(__version__) + ') \n' 
   header = header + 'https://apollinaire.readthedocs.io/en/latest \n' 
   header = header + 'File creation date: ' + dt_string + '\n' 
 
@@ -120,8 +120,8 @@ def make_header_pattern (author=None, fit_l1=True, fit_l3=False,
     str_args += 'nwalkers=' + str (nwalkers) + '\n' 
   if nsteps is not None :
     str_args += 'nsteps=' + str (nsteps) + '\n' 
-  if coeff_discard is not None :
-    str_args += 'discarded_steps=' + str (nsteps//coeff_discard) + '\n' 
+  if discard is not None :
+    str_args += 'discarded_steps=' + str (nsteps//discard) + '\n' 
   if n_order is not None :
     str_args += 'n_order=' + str (n_order) + '\n'
   str_args += '#######################\n'
@@ -132,7 +132,7 @@ def make_header_pattern (author=None, fit_l1=True, fit_l3=False,
   return header
 
 def make_header_pkb (extended=False, author=None, spectro=False, projected_splittings=False,
-                     nwalkers=None, nsteps=None, coeff_discard=None, fit_amp=False) :
+                     nwalkers=None, nsteps=None, discard=None, fit_amp=False) :
   '''
   Design pkb files header.
 
@@ -165,8 +165,8 @@ def make_header_pkb (extended=False, author=None, spectro=False, projected_split
     str_args += 'nwalkers=' + str (nwalkers) + '\n' 
   if nsteps is not None :
     str_args += 'nsteps=' + str (nsteps) + '\n' 
-  if coeff_discard is not None :
-    str_args += 'discarded_steps=' + str (nsteps//coeff_discard) + '\n' 
+  if discard is not None :
+    str_args += 'discarded_steps=' + str (discard) + '\n' 
   str_args += 'fit_amp=' + str (fit_amp) + '\n'
   str_args += '#######################\n'
   header = str_args + header
@@ -179,7 +179,7 @@ def make_header_pkb (extended=False, author=None, spectro=False, projected_split
   if author is not None :
     header = 'Peakbagging performed by ' + author + ' with apollinaire (v' + str(__version__) + ') \n' + header
   else :
-    header = 'Peakbagging performed by with apollinaire (v' + str(__version__) + ') \n' + header
+    header = 'Peakbagging performed with apollinaire (v' + str(__version__) + ') \n' + header
 
   return header
 
@@ -188,14 +188,14 @@ if __name__=='__main__' :
   print ('Example of pkb header for spectroscopic observation (extended case):')
   print ('--------------------------------------------------------------------')
   print (make_header_pkb (extended=True, author='G.A.V.A.A.K', spectro=True, 
-         projected_splittings=True, nwalkers=500, nsteps=500, coeff_discard=5))
+         projected_splittings=True, nwalkers=500, nsteps=500, discard=200))
   print ('Example of pkb header for photometric observation (reduced case):')
   print ('-----------------------------------------------------------------')
   print (make_header_pkb (extended=False, author='G.A.V.A.A.K', spectro=False))
   print ('Example of file header for background parameters:')
   print ('-----------------------------------------------------------------')
   print (make_header_background_param (n_harvey=2, author='G.A.V.A.A.K', 
-         nwalkers=500, nsteps=500, coeff_discard=5))
+         nwalkers=500, nsteps=500, discard=200))
   print ('Example of file header for pattern parameters:')
   print ('-----------------------------------------------------------------')
   print (make_header_pattern (author='G.A.V.A.A.K'))
