@@ -9,6 +9,7 @@ from .fit_tools import (read_a2z, plot_from_param, a2z_to_pkb, check_a2z,
 from .bayesian import wrap_explore_distribution 
 from .chain_reader import cf_to_pkb_extended
 from os import path
+import warnings
 
 def dnu_from_df (df_a2z) :
   '''
@@ -68,12 +69,12 @@ def define_window (df_a2z, strategy, dnu=135., do_not_use_dnu=False, size_window
       coeff = 37.5
     elif center_freq > 2000 :
       coeff = 27.5
-    elif center_freq > 1200 :
+    elif center_freq > 800 :
       coeff = 17.5
     if dnu is not None :
       low_bound = center_freq - coeff * dnu / 135.
       up_bound = center_freq + coeff * dnu / 135.
-    if (center_freq < 1200)|(do_not_use_dnu) :
+    if (center_freq < 800)|(do_not_use_dnu) :
       d = 1
       gap = up_freq - low_freq
       low_bound = low_freq - gap / d
@@ -180,21 +181,19 @@ def get_list_order (df_a2z) :
   return order
 
 def peakbagging (a2z_file, freq, psd, back=None, wdw=None, dnu=None,
-                 spectro=True, nsteps_mcmc=1000, show_corner=False, store_chains=False,
+                 spectro=True, nsteps_mcmc=1000, discard=200, 
+                 show_corner=False, store_chains=False,
                  mcmcDir='.', order_to_fit=None, parallelise=False, progress=False,
                  strategy='order', fit_02=True, fit_13=True, nwalkers=64, normalise=False,
                  instr='geometric', show_summary=False, filename_summary=None, show_prior=False,
-                 coeff_discard=50, use_sinc=False, asym_profile='nigam-kosovichev',
+                 use_sinc=False, asym_profile='nigam-kosovichev', thin=1, 
                  restrict=False, remove_asymmetry_outside_window=True, do_not_use_dnu=False,
                  save_only_after_sampling=False, size_window=None, fit_amp=False,
                  extended=False, projected_splittings=False, bins=100, existing_chains='read',
-                 fit_splittings=True, fit_angle=True, fit_amplitude_ratio=False) : 
+                 fit_splittings=True, fit_angle=True, fit_amplitude_ratio=False, dpi=300,
+                 format_cornerplot='pdf', estimate_autocorrelation=False) : 
   '''
-  Read an a2z input file with a prior guess of the modes to fit and return the
-  result of the peakbagging protocol processed over those modes.  Fitting
-  strategy is the following: pair 1-3 and 2-0 of same order are successively
-  fitted from low frequencies to high frequencies following a pseudo-global
-  strategy. This protocol is repeted n_process times. 
+  Perform the peakbagging process for a given set of modes. 
 
   :param a2z_file: name of the file to read the parameters.
   :type a2z_file: string
@@ -224,6 +223,9 @@ def peakbagging (a2z_file, freq, psd, back=None, wdw=None, dnu=None,
   :param nsteps_mcmc: number of steps to process into each MCMC exploration.
   :type nsteps_mcmc: int
 
+  :param discard: number of steps to discard into each MCMC exploration.
+  :type discard: int
+
   :param show_corner: if set to ``True``, show and save the corner plot for the
     posterior distribution sampling.
   :type show_corner: bool
@@ -244,7 +246,7 @@ def peakbagging (a2z_file, freq, psd, back=None, wdw=None, dnu=None,
     parallelise process.  Optional, default ``False``.
   :type parallelise: bool
 
-  :param strategy: strategy to use for the fit, ``order``, ``pair``,
+  :param strategy: strategy to use for the fit, ``pair``, ``order``, 
     ``global``. Optional, default ``order``. If 'pair' is used, a2z input must
     contain individual heights, widths and splittings for each degree. The
     ``global`` behaviour is experimental. 
@@ -271,11 +273,6 @@ def peakbagging (a2z_file, freq, psd, back=None, wdw=None, dnu=None,
     default ``False``.
   :type show_summary: bool
 
-  :param coeff_discard: coeff used to compute the number of values to discard
-    at the beginning of each MCMC : total amount of sampled values will be divided
-    by coeff_discard. Optional, default 50.
-  :type coeff_discard: int
-
   :param use_sinc: if set to ``True``, mode profiles will be computed using
     cardinal sinus and not Lorentzians.  No asymmetry term will be used if it is
     the case. Optional, default ``False``.
@@ -348,6 +345,14 @@ def peakbagging (a2z_file, freq, psd, back=None, wdw=None, dnu=None,
     this parameter is set to ``True``.  Optional, default ``True``. 
   :type fit_amplitude_ratio: bool
 
+  :param dpi: dot per inch value for figures.
+  :type dpi: int 
+
+  :param estimate_autocorrelation: if set to ``True``, the autocorrelation time
+    of the sampled chains will be estimated by ``emcee``. Optional, default
+    ``False``. 
+  :type estimate_autocorrelation: bool
+
   :return: a2z fitted modes parameters as a DataFrame, and corresponding pkb
     array (extended pkb array if extended is set to ``True``)
   :rtype: tuple of objects
@@ -360,7 +365,7 @@ def peakbagging (a2z_file, freq, psd, back=None, wdw=None, dnu=None,
     raise Exception ('Unknown asym_profile.')
 
   df_a2z = read_a2z (a2z_file)
-  check_a2z (df_a2z)
+  check_a2z (df_a2z, strategy=strategy)
   if dnu is None :
     dnu = dnu_from_df (df_a2z)
   if dnu is None :
@@ -407,9 +412,11 @@ def peakbagging (a2z_file, freq, psd, back=None, wdw=None, dnu=None,
                                low_bound_freq=low_bound, up_bound_freq=up_bound, wdw=wdw, nsteps=nsteps_mcmc,
                                show_corner=show_corner, filename=filename, parallelise=parallelise,
                                progress=progress, nwalkers=nwalkers, normalise=normalise, instr=instr,
-                               coeff_discard=coeff_discard, use_sinc=use_sinc, asym_profile=asym_profile,
+                               discard=discard, use_sinc=use_sinc, asym_profile=asym_profile, thin=thin,
                                save_only_after_sampling=save_only_after_sampling, fit_amp=fit_amp,
-                               projected_splittings=projected_splittings, bins=bins, existing_chains=existing_chains)
+                               projected_splittings=projected_splittings, bins=bins, existing_chains=existing_chains,
+                               transparent=False, facecolor='white', dpi=dpi, format_cornerplot=format_cornerplot,
+                               estimate_autocorrelation=estimate_autocorrelation)
     if centiles is not None :
       df_a2z = update_with_centiles (df_a2z, centiles, fit_amp=fit_amp)
       if extended :
@@ -466,9 +473,11 @@ def peakbagging (a2z_file, freq, psd, back=None, wdw=None, dnu=None,
                                    low_bound_freq=low_bound, up_bound_freq=up_bound, wdw=wdw, nsteps=nsteps_mcmc,
                                    show_corner=show_corner, filename=filename, parallelise=parallelise,
                                    progress=progress, nwalkers=nwalkers, normalise=normalise, instr=instr,
-                                   coeff_discard=coeff_discard, use_sinc=use_sinc, asym_profile=asym_profile,
+                                   discard=discard, use_sinc=use_sinc, asym_profile=asym_profile, thin=thin,
                                    save_only_after_sampling=save_only_after_sampling, fit_amp=fit_amp,
-                                   projected_splittings=projected_splittings, bins=bins, existing_chains=existing_chains)
+                                   projected_splittings=projected_splittings, bins=bins, existing_chains=existing_chains,
+                                   transparent=False, facecolor='white', dpi=dpi, format_cornerplot=format_cornerplot,
+                                   estimate_autocorrelation=estimate_autocorrelation)
         if centiles is not None :
           df_a2z = update_with_centiles (df_a2z, centiles, fit_amp=fit_amp)
           if extended :
@@ -486,6 +495,7 @@ def peakbagging (a2z_file, freq, psd, back=None, wdw=None, dnu=None,
 
           df_a2z.loc[(df_a2z[0]==str(n))&(df_a2z[1]=='0'), 6] = 0
           df_a2z.loc[(df_a2z[0]==str(n-1))&(df_a2z[1]=='2'), 6] = 0
+          df_a2z.loc[(df_a2z[0]==str(n))&(df_a2z[3]=='even'), 6] = 0
 
           up_bound, low_bound = define_window (df_a2z, strategy, dnu=dnu, do_not_use_dnu=do_not_use_dnu, size_window=size_window)
           df_a2z = check_leak (df_a2z, low_bound, up_bound)
@@ -511,9 +521,11 @@ def peakbagging (a2z_file, freq, psd, back=None, wdw=None, dnu=None,
                                      low_bound_freq=low_bound, up_bound_freq=up_bound, wdw=wdw, nsteps=nsteps_mcmc,
                                      show_corner=show_corner, filename=filename, parallelise=parallelise,
                                      progress=progress, nwalkers=nwalkers, normalise=normalise, instr=instr, 
-                                     coeff_discard=coeff_discard, use_sinc=use_sinc, asym_profile=asym_profile,
+                                     discard=discard, use_sinc=use_sinc, asym_profile=asym_profile, thin=thin,
                                      save_only_after_sampling=save_only_after_sampling, fit_amp=fit_amp,
-                                     projected_splittings=projected_splittings, bins=bins, existing_chains=existing_chains)
+                                     projected_splittings=projected_splittings, bins=bins, existing_chains=existing_chains,
+                                     transparent=False, facecolor='white', dpi=dpi, format_cornerplot=format_cornerplot,
+                                     estimate_autocorrelation=estimate_autocorrelation)
           if centiles is not None :
             df_a2z = update_with_centiles (df_a2z, centiles, fit_amp=fit_amp)
             if extended :
@@ -529,6 +541,7 @@ def peakbagging (a2z_file, freq, psd, back=None, wdw=None, dnu=None,
           print ('Fitting degrees 1 and 3')
           df_a2z.loc[(df_a2z[0]==str(n))&(df_a2z[1]=='1'), 6] = 0
           df_a2z.loc[(df_a2z[0]==str(n-1))&(df_a2z[1]=='3'), 6] = 0
+          df_a2z.loc[(df_a2z[0]==str(n))&(df_a2z[3]=='odd'), 6] = 0
 
           up_bound, low_bound = define_window (df_a2z, strategy, dnu=dnu, do_not_use_dnu=do_not_use_dnu, size_window=size_window)
           df_a2z = check_leak (df_a2z, low_bound, up_bound)
@@ -548,15 +561,18 @@ def peakbagging (a2z_file, freq, psd, back=None, wdw=None, dnu=None,
             param_prior = a2z_to_pkb (restrict_input (df_a2z))
             plot_from_param (param_prior, freq[(freq>low_bound)&(freq<up_bound)], psd[(freq>low_bound)&(freq<up_bound)], 
                              back=back[(freq>low_bound)&(freq<up_bound)], wdw=wdw, smoothing=10, spectro=spectro, correct_width=1.,
-                             show=show_prior, instr=instr, asym_profile=asym_profile, projected_splittings=projected_splittings)
+                             show=show_prior, instr=instr, asym_profile=asym_profile, projected_splittings=projected_splittings,
+                             transparent=False, facecolor='white', dpi=dpi)
 
           centiles = wrap_explore_distribution (df_in, freq, psd, back, 
                                      low_bound_freq=low_bound, up_bound_freq=up_bound, wdw=wdw, nsteps=nsteps_mcmc,
                                      show_corner=show_corner, filename=filename, parallelise=parallelise,
                                      progress=progress, nwalkers=nwalkers, normalise=normalise, instr=instr,
-                                     coeff_discard=coeff_discard, use_sinc=use_sinc, asym_profile=asym_profile,
+                                     discard=discard, use_sinc=use_sinc, asym_profile=asym_profile, thin=thin,
                                      save_only_after_sampling=save_only_after_sampling, fit_amp=fit_amp,
-                                     projected_splittings=projected_splittings, bins=bins, existing_chains=existing_chains)
+                                     projected_splittings=projected_splittings, bins=bins, existing_chains=existing_chains,
+                                     transparent=False, facecolor='white', dpi=dpi, format_cornerplot=format_cornerplot,
+                                     estimate_autocorrelation=estimate_autocorrelation)
           if centiles is not None :
             df_a2z = update_with_centiles (df_a2z, centiles, fit_amp=fit_amp)
             if extended :
@@ -579,7 +595,8 @@ def peakbagging (a2z_file, freq, psd, back=None, wdw=None, dnu=None,
   # show result
   plot_from_param (pkb, freq, psd, back=back, wdw=wdw, smoothing=10, spectro=spectro, correct_width=1.,
                    show=show_summary, filename=filename_summary, instr=instr, asym_profile=asym_profile,
-                   projected_splittings=projected_splittings)
+                   projected_splittings=projected_splittings, transparent=False, facecolor='white',
+                   dpi=dpi)
 
   return df_a2z, pkb
 
