@@ -3,10 +3,11 @@
 import numpy as np
 import pandas as pd
 import matplotlib.pyplot as plt
+from os import path
 from .background import (perform_mle_background, explore_distribution_background, 
-                         dnu_scale, numax_scale)
+                         dnu_scale, numax_scale, background_guess)
 from .global_pattern import (perform_mle_pattern, explore_distribution_pattern,
-                             list_order_to_fit, pattern_to_a2z)
+                             list_order_to_fit, pattern_to_a2z, first_guess_mcmc)
 from .mode_selection import select_mode_to_fit
 from .peakbagging import peakbagging
 from .fit_tools import *
@@ -14,32 +15,32 @@ from .header import *
 import warnings
 
 
-def stellar_framework (freq, psd, r, m, teff, nwalkers=64, dnu=None, back=None,
+def stellar_framework (freq, psd, r=1, m=1, teff=5770, nwalkers=64, dnu=None, back=None, wdw=None,
                        numax=None, Hmax=None, Wenv=None, epsilon=None, width=None, 
                        alpha=None, d02=None, d01=None, d13=None, n_harvey=2, low_cut=10.,
                        guess_back=None, low_bounds_back=None, up_bounds_back=None, 
                        frozen_param_back=None, power_law=False, high_cut_plaw=20., spectro=False, 
-                       filename_back='background', back_mcmc=True, back_mle=True,
+                       filename_back='background.png', back_mcmc=True, back_mle=False,
                        filemcmc_back='mcmc_sampler_background.h5', nsteps_mcmc_back=1000,
                        guess_pattern=None, low_bounds_pattern=None, up_bounds_pattern=None,
-                       pattern_mcmc=True, pattern_mle=True, n_order=3, n_order_peakbagging=3,
-                       h0_screening=False, 
-                       filename_pattern='pattern', filemcmc_pattern='mcmc_sampler_pattern.h5',
+                       pattern_mcmc=True, pattern_mle=False, n_order=3, n_order_peakbagging=3,
+                       h0_screening=False, format_cornerplot='pdf',  
+                       filename_pattern='pattern.png', filemcmc_pattern='mcmc_sampler_pattern.h5',
                        nsteps_mcmc_pattern=1000, parallelise=False, fit_l1=True, fit_l3=False,
                        use_numax_back=False,  progress=False, a2z_file='modes_param.a2z', a2z_in=None,
                        nsteps_mcmc_peakbagging=1000, mcmcDir='.', instr='geometric', amp_l=[1., 1.5, 0.7, 0.2],
-                       filename_peakbagging='summary_peakbagging.pdf', nopeakbagging=False,
-                       coeff_discard_back=5, coeff_discard_pattern=5, coeff_discard_pkb=5,
-                       thin_back=1, thin_pattern=1, quickfit=False, num=500,
+                       filename_peakbagging='summary_peakbagging.png', nopeakbagging=False,
+                       discard_back=200, discard_pattern=200, discard_pkb=200,
+                       thin_back=1, thin_pattern=1, thin_pkb=1, quickfit=False, num=500, num_numax=500,
                        reboxing_behaviour='advanced_reboxing', reboxing_strategy='median',
                        save_only_after_sampling=False, apodisation=False, fit_angle=False,
-                       guess_angle=90, fit_splittings=False, guess_split=0,
-                       fit_amplitude_ratio=False, frozen_harvey_exponent=False, 
+                       guess_angle=90, fit_splittings=False, fit_splittings_per_order_in_global=False, 
+                       guess_split=0, fit_amplitude_ratio=False, frozen_harvey_exponent=False, 
                        fit_amp=False, extended=False, author=None,
                        pkb_fmt=None, projected_splittings=False, bins=100,
                        existing_chains_back='read', existing_chains_pattern='read',
                        existing_chains_pkb='read', strategy='order', common_width=False,
-                       save_background_vector=True) :
+                       save_background_vector=True, dpi=300, show_corner=True, estimate_autocorrelation=False) :
 
   '''
   Framework for stellar peakbagging considering only a few input parameters.
@@ -51,13 +52,15 @@ def stellar_framework (freq, psd, r, m, teff, nwalkers=64, dnu=None, back=None,
   :param psd: real power or power spectral density vector
   :type psd: ndarray
 
-  :param r: stellar radius. Given in solar radius.
+  :param r: stellar radius. Given in solar radius. Optional, default 1.
   :type r: float
 
-  :param m: stellar mass. Given in solar masses. 
+  :param m: stellar mass. Given in solar masses.  
+    Optional, default 1.
   :type m: float
 
-  :param teff: stellar effective temperature. Given in Kelvins. 
+  :param teff: stellar effective temperature. Given in Kelvins.  
+    Optional, default 5770.
   :type teff: float
 
   :param nwalkers: number of walkers for the MCMC process. Optional, default 64.
@@ -75,6 +78,11 @@ def stellar_framework (freq, psd, r, m, teff, nwalkers=64, dnu=None, back=None,
     Optional, default ``None``.
   :type back: ndarray
 
+  :param wdw: observational window of the light curve to take into account 
+    the side lobes pattern in the modes. Must be 1 when an actuak observation
+    is acquired and zero otherwise. Optional, default ``None``.
+  :type wdw: ndarray
+
   :param numax: maximum of power in p-mode envelope. Must be given in µHz. 
     Optional, default ``None``.
   :type numax: float
@@ -212,6 +220,9 @@ def stellar_framework (freq, psd, r, m, teff, nwalkers=64, dnu=None, back=None,
     default ``False``.
   :type h0_screening: bool
 
+  :param format_cornerplot: set cornerplot file format. Optional, default ``pdf``.
+  :type format_cornerplot: str
+
   :param filename_pattern: name of the pdf file where the fitted global pattern parameters 
     and the plot of the fitted global pattern will be stored.
     Optional, default ``pattern``.
@@ -283,23 +294,17 @@ def stellar_framework (freq, psd, r, m, teff, nwalkers=64, dnu=None, back=None,
     not be fitted. Optional, default ``False``.  
   :type nopeakbagging: bool
 
-  :param coeff_discard_back: coefficient used to compute the number of values
-    to discard at the beginning of each MCMC sampled by the background step : total
-    amount of sampled values will be divided by coeff_discard. Optional, default
-    50.
-  :type coeff_discard: int
+  :param discard_back: number of step to discard for the background sampling.
+    Optional, default 200.
+  :type discard_back: int
 
-  :param coeff_discard_pattern: coefficient used to compute the number of
-    values to discard at the beginning of each MCMC sampled by the pattern step :
-    total amount of sampled values will be divided by coeff_discard. Optional,
-    default 50.
-  :type coeff_discard: int
+  :param discard_pattern: number of step to discard for the pattern sampling.
+    Optional, default 200.
+  :type discard_pattern: int
 
-  :param coeff_discard_pkb: coefficient used to compute the number of values to
-    discard at the beginning of each MCMC sampled by the peakbagging step : total
-    amount of sampled values will be divided by coeff_discard. Optional, default
-    50.
-  :type coeff_discard: int
+  :param discard_pkb: number of step to discard for the peakbagging sampling.
+    Optional, default 200.
+  :type discard_pkb: int
 
   :param thin_back: take only every ``thin`` steps from the chain sampled for
     backgrounds parameters. Optional, default 10. 
@@ -314,10 +319,18 @@ def stellar_framework (freq, psd, r, m, teff, nwalkers=64, dnu=None, back=None,
     ``False``. 
   :type quickfit: bool
 
-  :param num: number of point to consider in the degraded PSD if ``quickfit``
-    is set to True. Optional, default 500.
+  :param num: Only considered if ``quickfit=True``. 
+    Number of point in the resampled PSD, or target number of point
+    for region away from ``numax`` if ``advanced_reboxing`` is selected.
+    Optional, default ``5000``.
   :type num: int
 
+  :param num_numax: Only considered if ``quickfit=True`` 
+    and ``reboxing_behaviour=advanced_reboxing``. 
+    Number of resampling points in the ``numax`` region.
+    Optional, default ``1000``.
+  :type num_numax: int
+
   :param reboxing_behaviour: behaviour for ``quickfit`` new power vector
     computation. It can be ``smoothing``, ``reboxing`` or ``advanced_reboxing``.
     Optional, default ``advanced_reboxing``. 
@@ -350,6 +363,12 @@ def stellar_framework (freq, psd, r, m, teff, nwalkers=64, dnu=None, back=None,
     include mode splittings in the parameters to fit.  Optional, default ``False``.
   :type fit_splittings: bool
 
+  :param fit_splittings_per_order_in_global: if set to ``True`` and
+    ``fit_splittings=True`` with ``strategy='global'``, the peakbagging process
+    will include one mode splittings per order in the parameters to fit.  Optional,
+    default ``False``.
+  :type fit_splittings_per_order_in_global: bool
+
   :param guess_split: initial guess value for splittings. Will be taken into
     account only if ``fit_splittings`` is ``True``.  Optional, default 0.
   :type guess_split: float
@@ -420,9 +439,38 @@ def stellar_framework (freq, psd, r, m, teff, nwalkers=64, dnu=None, back=None,
     this option is set to ``True``. Optional, default ``True``.
   :type save_background_vector: bool
 
+  :param dpi: dot per inch value for figures.
+  :type dpi: int 
+
+  :param show_corner: if set to ``True``, corner plots will be shown and saved.
+    Optional, default ``True``.
+  :type show_corner: bool
+
+  :param estimate_autocorrelation: if set to ``True``, the autocorrelation time
+    of the sampled chains will be estimated by ``emcee``. Optional, default
+    ``False``. 
+  :type estimate_autocorrelation: bool
+
   :return: ``None``
   '''
 
+  norm_back = None
+  norm_pattern = None
+
+  if existing_chains_back in ['sample', 'read'] and back_mcmc:
+    if path.exists (filemcmc_back) :
+      back_mle=False
+      if guess_back is None :
+        if dnu is None :
+          dnu = dnu_scale (r, m)
+        if numax is None :
+          numax = numax_scale (r, m, teff)
+        guess_back = background_guess (freq, psd, numax, dnu, 
+                              m_star=m, n_harvey=n_harvey, 
+                              spectro=spectro, power_law=power_law,
+                              high_cut_plaw=high_cut_plaw)
+      norm_back = np.loadtxt (path.splitext (filemcmc_back)[0] + '.dat', usecols=0)
+
   if back_mle==False and back_mcmc==False :
     raise Exception ('You must set at least pattern_mcmc=True or pattern_mle=True')
 
@@ -444,25 +492,29 @@ def stellar_framework (freq, psd, r, m, teff, nwalkers=64, dnu=None, back=None,
                                 dnu=dnu, numax=numax, frozen_param=frozen_param_back, power_law=power_law,
                                 frozen_harvey_exponent=frozen_harvey_exponent, low_cut=low_cut, fit_log=True, quickfit=quickfit,
                                 low_bounds=low_bounds_back, up_bounds=up_bounds_back, no_bounds=False, high_cut_plaw=high_cut_plaw,
-                                show=False, show_guess=False, filename=filename_back+'.pdf', spectro=spectro,
-                                apodisation=apodisation, num=num, reboxing_behaviour=reboxing_behaviour, reboxing_strategy=reboxing_strategy)
+                                show=False, show_guess=False, filename=filename_back, spectro=spectro,
+                                apodisation=apodisation, num=num, num_numax=num_numax, 
+                                reboxing_behaviour=reboxing_behaviour, reboxing_strategy=reboxing_strategy,
+                                transparent=False, facecolor='white', dpi=dpi)
       np.savetxt (filename_back+'_parameters.dat', param_back, fmt='%-s', header=make_header_background_param (n_harvey=n_harvey, author=author, mcmc=False))
     else :
       param_back = guess_back
 
     if back_mcmc :
-      fitted_back, param_back, sigma_back = explore_distribution_background (freq, psd,
+      fitted_back, param_back, sigma_back = explore_distribution_background (freq, psd, dnu=dnu, 
                                        n_harvey=n_harvey, r=r, m=m, teff=teff, guess=param_back, frozen_param=frozen_param_back, power_law=power_law,
                                        frozen_harvey_exponent=frozen_harvey_exponent, low_cut=low_cut, fit_log=True, quickfit=quickfit,
-                                       low_bounds=low_bounds_back, up_bounds=up_bounds_back, spectro=spectro, show=False, show_guess=False, show_corner=True,
-                                       nsteps=nsteps_mcmc_back, filename=filename_back+'.pdf', parallelise=progress, progress=progress, nwalkers=nwalkers, 
-                                       filemcmc=filemcmc_back, coeff_discard=coeff_discard_back, thin=thin_back, 
+                                       low_bounds=low_bounds_back, up_bounds=up_bounds_back, spectro=spectro, 
+                                       show=False, show_guess=False, show_corner=show_corner, estimate_autocorrelation=estimate_autocorrelation,
+                                       nsteps=nsteps_mcmc_back, filename=filename_back, parallelise=progress, progress=progress, nwalkers=nwalkers, 
+                                       filemcmc=filemcmc_back, discard=discard_back, thin=thin_back, norm=norm_back, 
                                        save_only_after_sampling=save_only_after_sampling, high_cut_plaw=high_cut_plaw,
-                                       apodisation=apodisation, num=num, reboxing_behaviour=reboxing_behaviour,
-                                       reboxing_strategy=reboxing_strategy, bins=bins, existing_chains=existing_chains_back)
-      np.savetxt (filename_back+'_parameters.dat', np.c_[param_back, sigma_back], fmt='%-s', 
+                                       apodisation=apodisation, num=num, num_numax=num_numax, reboxing_behaviour=reboxing_behaviour,
+                                       reboxing_strategy=reboxing_strategy, bins=bins, existing_chains=existing_chains_back,
+                                       transparent=False, facecolor='white', dpi=dpi, format_cornerplot=format_cornerplot)
+      np.savetxt (path.splitext (filename_back)[0]+'_parameters.dat', np.c_[param_back, sigma_back], fmt='%-s', 
                   header=make_header_background_param (n_harvey=n_harvey, author=author, apodisation=apodisation,
-                                                       low_cut=low_cut, nwalkers=nwalkers, nsteps=nsteps_mcmc_back, coeff_discard=coeff_discard_back,
+                                                       low_cut=low_cut, nwalkers=nwalkers, nsteps=nsteps_mcmc_back, discard=discard_back,
                                                        reboxing_behaviour=reboxing_behaviour, quickfit=quickfit))
     
     if use_numax_back :
@@ -470,10 +522,10 @@ def stellar_framework (freq, psd, r, m, teff, nwalkers=64, dnu=None, back=None,
     Wenv = param_back[n_harvey*3+4] 
 
     if save_background_vector :
-      np.savetxt (filename_back+'.dat', fitted_back, fmt='%-s', 
+      np.savetxt (path.splitext(filename_back)[0]+'.dat', fitted_back, fmt='%-s', 
                   header=make_header_background_vector (author=author,apodisation=apodisation,
                                                         low_cut=low_cut, nwalkers=nwalkers, nsteps=nsteps_mcmc_back, 
-                                                        coeff_discard=coeff_discard_back,
+                                                        discard=discard_back,
                                                         reboxing_behaviour=reboxing_behaviour, quickfit=quickfit))
 
   else :
@@ -489,14 +541,25 @@ def stellar_framework (freq, psd, r, m, teff, nwalkers=64, dnu=None, back=None,
   if Hmax is None :
     Hmax = 0.5 * np.max (psd[(freq>0.99*numax)&(freq<1.01*numax)]) 
 
+
   if a2z_in is None :
+
+    if existing_chains_pattern in ['sample', 'read'] and pattern_mcmc:
+      if path.exists (filemcmc_pattern) :
+        pattern_mle=False
+        if guess_pattern is None :
+          guess_pattern = first_guess_mcmc (dnu, numax, teff, Hmax, Wenv, mass=m)
+        norm_pattern = np.loadtxt (path.splitext (filemcmc_pattern)[0] + '.dat', usecols=0)
+       
+
     if pattern_mle :
       df_a2z, pattern = perform_mle_pattern (dnu, numax, Hmax, Wenv, teff, freq, psd, back=fitted_back, 
-                                             wdw=None, epsilon=epsilon, width=width, alpha=alpha, d01=d01,
+                                             wdw=wdw, epsilon=epsilon, width=width, alpha=alpha, d01=d01,
                                              d02=d02, d13=d13, guess=guess_pattern, low_bounds=low_bounds_pattern,
                                              up_bounds=up_bounds_pattern, amp_l=amp_l,
                                              n_order=n_order, split=0, angle=90, fit_l1=fit_l1, 
-                                             fit_l3=fit_l3, mass=m, show=False, filename=filename_pattern+'.pdf')
+                                             fit_l3=fit_l3, mass=m, show=False, filename=filename_pattern,
+                                             transparent=False, facecolor='white', dpi=dpi)
       # Setting value to None to avoid overriding the MLE results at the MCMC step
       epsilon = None
       alpha = None
@@ -509,37 +572,47 @@ def stellar_framework (freq, psd, r, m, teff, nwalkers=64, dnu=None, back=None,
       pattern = guess_pattern
 
     if pattern_mcmc :
-      df_a2z, pattern, sigma_pattern = explore_distribution_pattern (dnu, numax, Hmax, Wenv, teff, freq, psd, back=fitted_back, wdw=None,
+      df_a2z, pattern, sigma_pattern = explore_distribution_pattern (dnu, numax, Hmax, Wenv, teff, freq, psd, back=fitted_back, wdw=wdw,
                                                                      n_order=n_order, split=0, angle=90, fit_l1=fit_l1, 
                                                                      fit_l3=fit_l3, mass=m, guess=pattern, low_bounds=low_bounds_pattern,
-                                                                     up_bounds=up_bounds_pattern, show=False,
-                                                                     show_corner=True, nsteps=nsteps_mcmc_pattern, 
-                                                                     filename=filename_pattern+'.pdf', parallelise=parallelise, progress=progress,
-                                                                     nwalkers=nwalkers, filemcmc=filemcmc_pattern, coeff_discard=coeff_discard_pattern, 
+                                                                     up_bounds=up_bounds_pattern, show=False, norm=norm_pattern,
+                                                                     show_corner=show_corner, nsteps=nsteps_mcmc_pattern, 
+                                                                     estimate_autocorrelation=estimate_autocorrelation,
+                                                                     filename=filename_pattern, parallelise=parallelise, progress=progress,
+                                                                     nwalkers=nwalkers, filemcmc=filemcmc_pattern, discard=discard_pattern, 
                                                                      thin=thin_pattern, save_only_after_sampling=save_only_after_sampling, 
                                                                      bins=bins, existing_chains=existing_chains_pattern,
                                                                      epsilon=epsilon, alpha=alpha, width=width,
-                                                                     d02=d02, d01=d01, d13=d13, amp_l=amp_l)
+                                                                     d02=d02, d01=d01, d13=d13, amp_l=amp_l, 
+                                                                     format_cornerplot=format_cornerplot,
+                                                                     transparent=False, facecolor='white', dpi=dpi)
 
-      np.savetxt (filename_pattern+'.dat', np.c_[pattern, sigma_pattern], fmt='%-s', 
+      np.savetxt (path.splitext (filename_pattern)[0]+'.dat', np.c_[pattern, sigma_pattern], fmt='%-s', 
                   header=make_header_pattern (author=author, fit_l1=fit_l1, fit_l3=fit_l3))
 
     else : 
-      np.savetxt (filename_pattern+'.dat', pattern, fmt='%-s', 
+      np.savetxt (path.splitext (filename_pattern)[0]+'.dat', pattern, fmt='%-s', 
                   header=make_header_pattern (author=author, fit_l1=fit_l1, fit_l3=fit_l3,
                                               nwalkers=nwalkers, nsteps=nsteps_mcmc_pattern, 
-                                              coeff_discard=coeff_discard_pattern,
+                                              discard=discard_pattern,
                                               n_order=n_order))
     if h0_screening :
       n_order_peakbagging = 20
     orders_for_peakbagging = list_order_to_fit (numax, dnu, n_order=n_order_peakbagging) 
     if strategy=='global' :
       # This will avoid creating an angle and splittings parameter per order if the fitting
-      # strategy is set on 'global'.
+      # strategy is set on 'global'. Remember that ``fit_splittings_per_order_in_global``
+      # allows fitting one splittings per order even in ``strategy='global'``.
+      fit_a = fit_angle
+      fit_s = fit_splittings
       fit_angle = False
-      fit_splittings = False
+      fit_splittings = fit_splittings_per_order_in_global
     df_a2z = pattern_to_a2z (*pattern, split=guess_split, angle=guess_angle, orders=orders_for_peakbagging, angle_order=fit_angle, 
                              splitting_order=fit_splittings, common_width=common_width, amp_l=amp_l)
+    if strategy=='global' :
+      fit_angle = fit_a
+      fit_splittings = fit_s
+
     if h0_screening :
       #Max rebinning is at 5 muHz (arbitrary) or 99 bin
       tmax = min (5 / np.median (np.diff (freq)), 99)
@@ -553,16 +626,17 @@ def stellar_framework (freq, psd, r, m, teff, nwalkers=64, dnu=None, back=None,
       a2z_to_read = a2z_in
      
     df_a2z, pkb = peakbagging (a2z_to_read, freq, psd, back=fitted_back,
-                               wdw=None, spectro=spectro, nsteps_mcmc=nsteps_mcmc_peakbagging,
-                               show_corner=True, store_chains=True, mcmcDir=mcmcDir, order_to_fit=None,
+                               wdw=wdw, spectro=spectro, nsteps_mcmc=nsteps_mcmc_peakbagging,
+                               show_corner=show_corner, store_chains=True, mcmcDir=mcmcDir, order_to_fit=None,
                                parallelise=parallelise, progress=progress, strategy=strategy,
-                               nwalkers=nwalkers, normalise=False, instr=instr,
+                               nwalkers=nwalkers, normalise=False, instr=instr, thin=thin_pkb,
                                filename_summary=filename_peakbagging, show_summary=False,
-                               coeff_discard=coeff_discard_pkb,
+                               discard=discard_pkb, format_cornerplot=format_cornerplot,
                                save_only_after_sampling=save_only_after_sampling, restrict=True,
                                fit_amp=fit_amp, extended=extended, projected_splittings=projected_splittings,
                                bins=bins, existing_chains=existing_chains_pkb, fit_splittings=fit_splittings,
-                               fit_angle=fit_angle, fit_amplitude_ratio=fit_amplitude_ratio)
+                               fit_angle=fit_angle, fit_amplitude_ratio=fit_amplitude_ratio, dpi=dpi,
+                               estimate_autocorrelation=estimate_autocorrelation)
 
     save_a2z (a2z_file, df_a2z)
 
@@ -571,9 +645,9 @@ def stellar_framework (freq, psd, r, m, teff, nwalkers=64, dnu=None, back=None,
     pkb = sort_pkb (pkb)
     extended = False
   
-  save_pkb (a2z_file[:len(a2z_file)-3]+'pkb', pkb, fmt=pkb_fmt, 
+  save_pkb (path.splitext (a2z_file)[0]+'.pkb', pkb, fmt=pkb_fmt, 
             author=author, extended=extended, spectro=spectro, 
             projected_splittings=projected_splittings, nwalkers=nwalkers, nsteps=nsteps_mcmc_peakbagging, 
-            coeff_discard=coeff_discard_pkb, fit_amp=fit_amp) 
+            discard=discard_pkb, fit_amp=fit_amp) 
 
   return 
