@@ -6,4 +6,5 @@ from .cross_correlate import *
 
 from .metrics import *
 
-from .degrade_psd import degrade_psd
+from .degrade_psd import (degrade_psd,
+                          create_log_freq)
