@@ -40,7 +40,7 @@ def create_noise_vector (freq, entropy=None) :
 
 def create_synthetic_psd (freq, pkb=None, back=None, param_back=None, n_harvey=2, wdw=None,
                           feature=None, instr='geometric', asym_profile='nigam-kosovichev', 
-                          use_sinc=False, entropy=None, noise_free=False) :
+                          use_sinc=False, entropy=None, noise_free=False, fit_amp=False) :
   '''
   Create a synthetic psd vector from a frequency vector,
   modes parameters from a pkb arrays and, optionnally,
@@ -114,7 +114,7 @@ def create_synthetic_psd (freq, pkb=None, back=None, param_back=None, n_harvey=2
   if pkb is None :
     model = np.zeros (freq.size)
   else :
-    model = compute_model (freq, pkb, param_wdw=param_wdw, instr=instr, 
+    model = compute_model (freq, pkb, param_wdw=param_wdw, instr=instr, fit_amp=fit_amp,  
                            asym_profile=asym_profile, use_sinc=use_sinc)
   model = model + back
 
