@@ -89,6 +89,7 @@ def daily_correction_1d (s, v, f,
     v[v<25.] = np.nan
   
     #INSIDE BOX CORRECTIONS
+    count_removed = 0
     for stamp in rs :
       if stamp < s[0] - 0.5*dt/86400. :
         continue
@@ -97,7 +98,9 @@ def daily_correction_1d (s, v, f,
       box = v[np.abs (s - stamp) < 0.5*dt / 86400.] 
       box[np.abs (box-np.nanmean (box)) > sigma_box[0] * np.nanstd (box)] = np.nan
       box[np.abs (box-np.nanmean (box)) > sigma_box[1] * np.nanstd (box)] = np.nan
+      count_removed += np.count_nonzero (np.isnan(box))
       v[np.abs (s - stamp) < 0.5*dt / 86400.] = box
+    print ('Removed {:.0f} values from the inside box correction.'.format (count_removed))
   
   
     # 1 - centering the noon value at 0
@@ -111,13 +114,10 @@ def daily_correction_1d (s, v, f,
       ax1 = fig.add_subplot (111)
       ax2 = ax1.twinx ()
       ax1.scatter (s-origin, v-vephem, color='black', s=6, marker='.')
-      #ax1.scatter (s-origin, vephem, color='blue', s=6, marker='.')
-      #ax1.scatter (s-origin, v, color='orange', s=6, marker='.')
       ax2.plot (s-origin, f, color='slategrey')
       ax1.set_xlabel ('Time (day)')
       ax1.set_ylabel ('Velocity (m/s)')
       ax2.set_ylabel ('Photon flux level')
-      #plt.show ()
   
   
     #3 - NEIGHBORHOOD OUTLIERS CORRECTION
@@ -150,6 +150,7 @@ def daily_correction_1d (s, v, f,
   
       # WITHOUT LOWESS
       else :
+        count_removed = 0
         for stamp in ns :
           if stamp < s[0] - 0.5*dt*size_neighborhood/86400. :
             continue
@@ -160,7 +161,9 @@ def daily_correction_1d (s, v, f,
           aux_metric = neighborhood - vephem_n
           neighborhood[np.abs (aux_metric-np.nanmean (aux_metric)) > sigma_neighborhood[0] * np.nanstd (aux_metric)] = np.nan
           neighborhood[np.abs (aux_metric-np.nanmean (aux_metric)) > sigma_neighborhood[1] * np.nanstd (aux_metric)] = np.nan
+          count_removed += np.count_nonzero (np.isnan (neighborhood))
           v[np.abs (s - stamp) < 0.5 * size_neighborhood * dt / 86400.] = neighborhood 
+        print ('Removed {:.0f} values from the neighbourhood correction.'.format (count_removed))
   
     if plot==True :
       ax1.scatter (s-origin, v-vephem, color='deepskyblue', s=6, marker='.')
@@ -262,7 +265,7 @@ def global_correction (s, v, f, filt=None, sigma_global=[3.5,3.],
     v[mask_zero] = 0
 
     n_value = np.count_nonzero (v)
-    print (n_value / v.size)
+    print ('Daily duty_cycle: {:.1f} %'.format (100 * n_value / v.size))
 
     return v
 
@@ -340,7 +343,7 @@ def plot_result_reduction (s, v, f=None, s_comp=None, v_comp=None, dt=20., dt_co
     psd = psd / dc
     noise_metric = levels (freq, psd, verbose=True) 
     
-    fig = plt.figure (figsize=(12,6))
+    fig = plt.figure (figsize=(24,12))
     ax1 = fig.add_subplot (211)
     ax2 = fig.add_subplot (223)
     ax3 = fig.add_subplot (224)
